@@ -1,4 +1,4 @@
-#!/bin/sh
+﻿#!/bin/sh
 # cd /usr/lib/hildon-desktop
 # python2.5 /usr/lib/hildon-desktop/bluezwitch.py
 
@@ -63,7 +63,7 @@ class BluezwitchHomePlugin(hildondesktop.HomePluginItem):
     self.hbox = gtk.HBox()
     self.vbox = gtk.VBox()
     self.e_eventbox = gtk.EventBox()
-    self.e_eventbox.set_size_request(48, 64) 
+    self.e_eventbox.set_size_request(64, 72)           
     self.e_eventbox.set_events(gtk.gdk.BUTTON_PRESS_MASK)
     self.e_eventbox.connect("button-release-event", self.on_toggle)
     self.hbox.pack_start(self.e_eventbox, True, True, 10)
